import { throttle } from "lodash";
import { createLog } from "./logger";

export function toChineseNumber(num) {
  let ret;
  if (num < 10) {
    ret = num.toLocaleString("zh-u-nu-hanidec");
  } else if (num === 10) {
    ret = "十";
  } else if (num > 10 && num < 20) {
    ret = "十" + (num % 10).toLocaleString("zh-u-nu-hanidec");
  } else if (num >= 20 && num < 100) {
    let s = num
      .toLocaleString("zh-u-nu-hanidec", { useGrouping: false })
      .split("");
    s.splice(1, 0, "十");
    ret = s.join("").replace("〇", "");
  } else {
    ret = num.toLocaleString("zh-u-nu-hanidec"); // 假设没有超过100的大题
  }

  return ret;
}

// 如果这台机器上登录过的学生人数小于5，那么这台电脑就是学生的
export function isThisMachineOwnByStudent() {
  return (JSON.parse(localStorage.getItem("userIds")) || []).length < 5;
}

export function setUUID() {
  if (!localStorage.getItem("uuidForEcs")) {
    const uuidForEcs = "" + Date.now() + Math.random();
    localStorage.setItem("uuidForEcs", uuidForEcs);
  }
}

export function isElectron() {
  return typeof nodeRequire != "undefined";
}

export function registerOnResize() {
  const throttledResizeLog = throttle(() => {
    createLog({
      page: window.location.pathname,
      action: "registerOnResize",
      width: window.screen.width,
      height: window.screen.height,
      screenX: window.screen.availWidth,
      screenY: window.screen.availHeight,
      clientWidth: document.documentElement.clientWidth,
      clientHeight: document.documentElement.clientHeight,
      windowInnerWidth: window.innerWidth,
      windowInnerHeight: window.innerHeight,
      windowOuterWidth: window.outerWidth,
      windowOuterHeight: window.outerHeight,
    });
  }, 3000);
  window.onresize = throttledResizeLog;
}

// 下载文件
export async function downloadFileURL(url, name) {
  const link = document.createElement("a");
  link.style.display = "none";
  const fileName = name || url.split("/").pop().split("?")[0];
  console.log(fileName);
  link.setAttribute("download", fileName);

  link.href = url;
  document.body.appendChild(link);
  link.click();
  document.body.removeChild(link);
}

export function checkMainExe() {
  let iid = window.nodeRequire("process").pid;
  iid = window
    .nodeRequire("child_process")
    .execSync(
      `cmd /c chcp 65001>nul && wmic process where ^(processid^=${iid}^) get parentprocessid /value`
    )
    .toString();
  const executablePath = window
    .nodeRequire("child_process")
    .execSync(
      `cmd /c chcp 65001>nul && wmic process where ^(processid^=${iid}^) get executablepath`
    )
    .toString();
  const getHash = window
    .nodeRequire("crypto")
    .createHmac("sha256", "abcdefg")
    .update(window.nodeRequire("fs").readFileSync(executablePath))
    .digest("hex");
  console.log("the hash: ", getHash);
  // check filepath executablePath md5
}
